﻿using Apollo.CK.Web;
using RS.Lib;
using RS.Lib.Utils;
using RS.Web;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Web;

namespace Apollo.CS.Web
{
    /// <summary>
    /// 上传组件控制程序，用于处理上传信息
    /// </summary>
    public class PhotoBoxHandler : IHttpHandler
    {

        public void ProcessRequest(HttpContext context)
        {
            context.Response.ContentType = "text/plain";
            

            string Command=WebHelper.GetRequestValue("Command");
            if (Command=="Upload") //是上传图片
                context.Response.Write(WebHelper.JSON.Serialize(SaveUploadPhoto(context)));
            else if (Command=="Delete") //是删除图片
                context.Response.Write(WebHelper.JSON.Serialize(DeleteUploadPhoto(context)));
            else
                context.Response.Write(WebHelper.JSON.Serialize(JsonReturn.RunFail("未知操作")));
        }

        public JsonReturn DeleteUploadPhoto(HttpContext context)
        {
            string file=WebHelper.GetRequestValue("File");
            if (file.IsNotWhiteSpace() && File.Exists(file))
            {
                try{
                    File.Delete(file);
                }
                catch{}
            }
            return JsonReturn.RunSuccess(true);
        }
        #region 图片上传
        
        /// <summary>
        /// 保存上传的图片
        /// </summary>
        /// <returns></returns>
        public JsonReturn SaveUploadPhoto(HttpContext context)
        {
            try
            {
                string dataJson = WebHelper.GetRequestValue("ApolloPhotoData");
                DynamicObj data = WebHelper.JSON.Deserialize<DynamicObj>(dataJson);

                int imgWH = data.Get<int>("ImageMaxWH");//图片最大宽高
                if (imgWH == 0) imgWH = 1024;

                string PathName = data.Get<string>("PathName");
                if (PathName.IsWhiteSpace()) PathName = "CKPhoto/UserPhoto";

                if (context.Request.Files.Count > 0)//上传了文件
                {
                    var file = context.Request.Files["ApolloPhotoBox"];
                    if (file != null)
                    {
                        if (!file.ContentType.StartsWith("image/"))
                            return JsonReturn.RunFail("只能上传图片文件");


                        Image oldimg = Image.FromStream(file.InputStream);
                        Image img = ImgHelper.GetThumbnail(oldimg, imgWH);//压缩为500宽

                        //配置存放的根目录
                        string uploadPath = LibHelper.GetAppSetting("RSUPFilePath");
                        //配置访问的目录
                        string webVirPath = LibHelper.GetAppSetting("RSUPVirthPath");
                        UploadPathInfo pathInfo = PathUtils.CreateUploadPath(PathName, UploadPathType.MonthlyChildDir, uploadPath, webVirPath);

                        //上传的图片暂存为如下格式：uh20160816_AB0000000001
                        string en = Path.GetExtension(file.FileName);
                        if (en.StartsWith("."))
                        {
                            if (en.Length > 1)
                                en = en.Substring(1);
                            else
                                en = "";
                        }
                        string fn = string.Format("{0}.{1}", PathUtils.CreateUpFileNameNoExp("", UploadFielNameType.RandomName), en);
                        img.Save(Path.Combine(pathInfo.PhysicalPath, fn));

                        return JsonReturn.RunSuccess(new { vfile = string.Format("{0}/{1}", pathInfo.VirthPath, fn), file = string.Format("{0}\\{1}", pathInfo.PhysicalPath, fn) });
                    }
                    else
                        return JsonReturn.RunFail("未上传图片");
                }
                else
                    return JsonReturn.RunFail("未上传图片");
            }
            catch (Exception ex)
            {
                return JsonReturn.RunFail("上传图片时出现异常，原因：" + ex.Message);
            }
        }

        #endregion



        public bool IsReusable
        {
            get
            {
                return false;
            }
        }
    }
}